<?php

declare(strict_types=1);

namespace Doctrine\DBAL\Exception;

class DatabaseDoesNotExist extends DatabaseObjectNotFoundException
{
}
